@@ -95,7 +95,7 @@ def _traverse_all_imported_python_files(file_full_path):
 
 
 @splunk_appinspect.tags(
-    "splunk_appinspect", "cloud", "self-service", "future",
+    "splunk_appinspect", "cloud", "self-service"
 )
 def check_idx_binary_compatibility(app, reporter):
     """Checks that binaries that are distributed to the IDX tier of a distributed Splunk platform deployment are
@@ -155,7 +155,7 @@ def check_idx_binary_compatibility(app, reporter):
             invalid_files.update(traversed_invalid_files)
         elif binary_status["binary"] and not binary_status["arm"]:
             # Change from warning to fail 3 months after deploying
-            reporter.warn(
+            reporter.fail(
                 f"The following file is incompatible with the ARM aarch64 architecture. "
                 f"Compatibility with this architecture is required for code that will be executed "
                 f"on the Indexer tier of the Splunk Cloud Platform.",
