@@ -101,7 +101,7 @@ def check_command_scripts_python_version(app, reporter, target_splunk_version):
                     except Exception as ex:
                         reporter.fail(
                             f"Custom command {command.name} defines a script that is not Python 3 compatible. "
-                            f'The error is "{ex}". ',
+                            f'The error is "{ex}". '
                             "Upgrade your Python script to be Python 3 compatible.",
                             os.path.join("bin", command.file_name),
                         )
