@@ -81,12 +81,6 @@ def check_hotlinking_splunk_web_libraries(app, reporter):
             __file__, "../../splunk/jquery_checks_data/disallowed_imports.json"
         )
     )
-    # Get list of files from search head (disallowed_imports_2.json)
-    disallowed_json_path_2 = os.path.abspath(
-        os.path.join(
-            __file__, "../../splunk/jquery_checks_data/disallowed_imports_2.json"
-        )
-    )
     # Get list of risky imports from search head (risky_imports.json)
     risky_imports_json_path = os.path.abspath(
         os.path.join(__file__, "../../splunk/jquery_checks_data/risky_imports.json")
@@ -98,12 +92,6 @@ def check_hotlinking_splunk_web_libraries(app, reporter):
         disallowed_modules_imports = util.populate_set_from_json(
             disallowed_modules_file
         )
-    with open(
-        disallowed_json_path_2, "r", encoding="utf-8", errors="ignore"
-    ) as disallowed_modules_file_2:
-        disallowed_modules_imports_2 = util.populate_set_from_json(
-            disallowed_modules_file_2
-        )
     with open(
         risky_imports_json_path, "r", encoding="utf-8", errors="ignore"
     ) as risky_imports_file:
@@ -114,7 +102,6 @@ def check_hotlinking_splunk_web_libraries(app, reporter):
         unpacked_js_files,
         unpacked_html_files,
         disallowed_modules_imports,
-        disallowed_modules_imports_2,
         risky_modules_imports,
     )
     util.communicate_bad_import_message(reporter, file_list)
