@@ -46,6 +46,8 @@ def app_package_extractable(check):
     "packaging_standards",
     "self-service",
     "private_app",
+    "private_victoria",
+    "private_classic"
 )
 @splunk_appinspect.cert_version(min="1.5.0")
 @app_package_extractable
@@ -69,6 +71,8 @@ def check_that_splunk_app_package_has_read_permission(app, reporter):
     "packaging_standards",
     "self-service",
     "private_app",
+    "private_victoria",
+    "private_classic"
 )
 @splunk_appinspect.cert_version(min="1.5.0")
 def check_that_splunk_app_package_valid_compressed_file(app, reporter):
@@ -88,6 +92,8 @@ def check_that_splunk_app_package_valid_compressed_file(app, reporter):
     "packaging_standards",
     "self-service",
     "private_app",
+    "private_victoria",
+    "private_classic"
 )
 @splunk_appinspect.cert_version(min="1.5.0")
 def check_that_splunk_app_package_name_does_not_start_with_period(app, reporter):
@@ -118,6 +124,8 @@ def check_that_splunk_app_package_name_does_not_start_with_period(app, reporter)
     "packaging_standards",
     "self-service",
     "private_app",
+    "private_victoria",
+    "private_classic"
 )
 @splunk_appinspect.cert_version(min="1.5.0")
 def check_that_splunk_app_package_extracts_to_visible_directory(app, reporter):
@@ -141,6 +149,8 @@ def check_that_splunk_app_package_extracts_to_visible_directory(app, reporter):
     "packaging_standards",
     "self-service",
     "private_app",
+    "private_victoria",
+    "private_classic"
 )
 @splunk_appinspect.cert_version(min="1.5.3")
 @app_package_extractable
@@ -188,6 +198,8 @@ def check_that_splunk_app_package_does_not_contain_files_outside_of_app(app, rep
     "packaging_standards",
     "self-service",
     "private_app",
+    "private_victoria",
+    "private_classic"
 )
 @splunk_appinspect.cert_version(min="1.5.3")
 @app_package_extractable
@@ -242,6 +254,8 @@ def check_that_splunk_app_package_with_static_dependencies_has_exactly_one_app_f
     "packaging_standards",
     "self-service",
     "private_app",
+    "private_victoria",
+    "private_classic"
 )
 @splunk_appinspect.cert_version(min="1.5.3")
 @app_package_extractable
@@ -283,6 +297,8 @@ def check_that_splunk_app_package_with_static_dependencies_has_app_manifest(
     "packaging_standards",
     "self-service",
     "private_app",
+    "private_victoria",
+    "private_classic"
 )
 @splunk_appinspect.cert_version(min="1.5.3")
 @app_package_extractable
@@ -339,6 +355,8 @@ def check_that_splunk_app_package_has_valid_static_dependencies(app, reporter):
     "packaging_standards",
     "self-service",
     "private_app",
+    "private_victoria",
+    "private_classic"
 )
 @splunk_appinspect.cert_version(min="1.5.0")
 @app_package_extractable
@@ -368,6 +386,8 @@ def check_that_extracted_splunk_app_does_not_contain_prohibited_directories_or_f
     "packaging_standards",
     "self-service",
     "private_app",
+    "private_victoria",
+    "private_classic"
 )
 @splunk_appinspect.cert_version(min="1.5.0")
 def check_that_extracted_splunk_app_contains_default_app_conf_file(app, reporter):
@@ -390,6 +410,8 @@ def check_that_extracted_splunk_app_contains_default_app_conf_file(app, reporter
     "packaging_standards",
     "self-service",
     "private_app",
+    "private_victoria",
+    "private_classic"
 )
 @splunk_appinspect.cert_version(min="1.5.0")
 def check_that_extracted_splunk_app_contains_default_app_conf_file_with_valid_version_number(
@@ -447,6 +469,8 @@ def check_that_extracted_splunk_app_contains_default_app_conf_file_with_valid_ve
     "packaging_standards",
     "self-service",
     "private_app",
+    "private_victoria",
+    "private_classic"
 )
 @splunk_appinspect.cert_version(min="1.5.0")
 @app_package_extractable
@@ -471,6 +495,8 @@ def check_that_extracted_splunk_app_does_not_contain_invalid_directories(app, re
     "packaging_standards",
     "self-service",
     "private_app",
+    "private_victoria",
+    "private_classic"
 )
 @splunk_appinspect.cert_version(min="1.5.0")
 @app_package_extractable
