@@ -97,6 +97,8 @@ def check_for_secret_disclosure(app, reporter):
             continue
         if _secret_disclosure_values_whitelist(result):
             continue
+        if _conf_options_secret_disclosure_whitelist(file_path, result):
+            continue
         reporter_output = (
             "The following line will be inspected during code review."
             "Possible secret disclosure found."
@@ -166,6 +168,32 @@ def _secret_disclosure_values_whitelist(line_message):
     return False
 
 
+def _conf_options_secret_disclosure_whitelist(file_path, line_message):
+    """Checks if the line message matched by the secret disclosure regex
+    is a whitelisted configuration option.
+    :param file_path: the file path of this matched line
+    :param line_message: the line message matched by secret_patterns regex in check_for_secret_disclosure
+    :return: True or False
+    """
+
+    # List of all configuration files and the options that have been whitelisted
+    conf_options_whitelist = {
+        os.path.join("default", "savedsearches.conf"): [
+                "action.email.show_password"
+        ]
+    }
+
+    # Iterate through each configuration file that have whitelisted options and
+    # check to see if it matches the line message
+    for configuration_file, whitelist_options in conf_options_whitelist.items():
+        if file_path == configuration_file:
+            for whitelist_option in whitelist_options:
+                if re.search(whitelist_option, line_message):
+                    return True
+
+    return False
+
+
 def _secret_disclosure_commands_whitelist(file_path, messages):
     """
     :param file_path: the file path of this matched line
@@ -413,66 +441,67 @@ def check_symlink_outside_app(app, reporter):
                     reporter.fail(reporter_output, app_file_path)
 
 
-# def check_for_supported_tls(app, reporter):
-#     """Check that all outgoing connections use TLS in accordance to Splunk Cloud Platform policy."""
-#     client = app.python_analyzer_client
-#
-#     def _report_if_all_kwrgs_found(
-#         ast_info, file_path, reporter, lib_name, check_kwrgs
-#     ):
-#         usages = ast_info.get_module_function_call_usage(lib_name, fuzzy=True)
-#         for usage in usages:
-#             find_count = 0
-#             if hasattr(usage, "keywords"):
-#                 for keyword in usage.keywords:
-#                     if (
-#                         hasattr(keyword, "arg")
-#                         and hasattr(keyword, "value")
-#                         and hasattr(keyword.value, "value")
-#                     ):
-#                         for k, v in check_kwrgs.items():
-#                             if keyword.arg == k and keyword.value.value == v:
-#                                 find_count = find_count + 1
-#             if find_count == len(check_kwrgs):
-#                 reporter_output = (
-#                     f"If you are using {lib_name} to talk to your own infra with non-public PKI, "
-#                     f"make sure you bundle your own CA certs as part of your app and pass the path "
-#                     f"into {lib_name} as an arg."
-#                 )
-#                 reporter.warn(reporter_output, file_path, usage.lineno)
-#
-#     for file_path, ast_info in client.get_all_ast_infos():
-#         _report_if_all_kwrgs_found(
-#             ast_info,
-#             file_path,
-#             reporter,
-#             "http.client.HTTPSConnection",
-#             {"cert_file": None},
-#         )
-#         _report_if_all_kwrgs_found(
-#             ast_info,
-#             file_path,
-#             reporter,
-#             "urllib.request.urlopen",
-#             {
-#                 "cafile": None,
-#                 "capath": None,
-#             },
-#         )
-#         _report_if_all_kwrgs_found(
-#             ast_info,
-#             file_path,
-#             reporter,
-#             "httplib2.Http",
-#             {"disable_ssl_certificate_validation": False},
-#         )
-#         for request_method in (
-#             "requests.request",
-#             "requests.get",
-#             "requests.post",
-#             "requests.patch",
-#             "requests.put",
-#         ):
-#             _report_if_all_kwrgs_found(
-#                 ast_info, file_path, reporter, request_method, {"verify": False}
-#             )
+@splunk_appinspect.tags("cloud", "privaite_app", "splunk_9_0", "future", "private_victoria", "private_classic", "pura")
+def check_for_supported_tls(app, reporter):
+    """Check that all outgoing connections use TLS in accordance to Splunk Cloud Platform policy."""
+    client = app.python_analyzer_client
+
+    def _report_if_all_kwrgs_found(
+        ast_info, file_path, reporter, lib_name, check_kwrgs
+    ):
+        usages = ast_info.get_module_function_call_usage(lib_name, fuzzy=True)
+        for usage in usages:
+            find_count = 0
+            if hasattr(usage, "keywords"):
+                for keyword in usage.keywords:
+                    if (
+                        hasattr(keyword, "arg")
+                        and hasattr(keyword, "value")
+                        and hasattr(keyword.value, "value")
+                    ):
+                        for k, v in check_kwrgs.items():
+                            if keyword.arg == k and keyword.value.value == v:
+                                find_count = find_count + 1
+            if find_count == len(check_kwrgs):
+                reporter_output = (
+                    f"If you are using {lib_name} to talk to your own infra with non-public PKI, "
+                    f"make sure you bundle your own CA certs as part of your app and pass the path "
+                    f"into {lib_name} as an arg."
+                )
+                reporter.warn(reporter_output, file_path, usage.lineno)
+
+    for file_path, ast_info in client.get_all_ast_infos():
+        _report_if_all_kwrgs_found(
+            ast_info,
+            file_path,
+            reporter,
+            "http.client.HTTPSConnection",
+            {"cert_file": None},
+        )
+        _report_if_all_kwrgs_found(
+            ast_info,
+            file_path,
+            reporter,
+            "urllib.request.urlopen",
+            {
+                "cafile": None,
+                "capath": None,
+            },
+        )
+        _report_if_all_kwrgs_found(
+            ast_info,
+            file_path,
+            reporter,
+            "httplib2.Http",
+            {"disable_ssl_certificate_validation": False},
+        )
+        for request_method in (
+            "requests.request",
+            "requests.get",
+            "requests.post",
+            "requests.patch",
+            "requests.put",
+        ):
+            _report_if_all_kwrgs_found(
+                ast_info, file_path, reporter, request_method, {"verify": False}
+            )
