@@ -3,18 +3,14 @@
 """This is a helper module to encapsulate the functionality that represents
 Splunk's modular inputs feature.
 """
-
-# Python Standard Libraries
-# py 2/3 compatible
 try:
     import itertools.ifilter as filter
 except ImportError:
     pass
 import logging
-import re
 import os
+import re
 
-# Custom Libraries
 import splunk_appinspect
 
 logger = logging.getLogger(__name__)
@@ -105,8 +101,8 @@ class ModularInputs(object):
     # TODO: generalize this to accept the filename and directory
     def has_specification_file(self):
         """Returns:
-            Returns a boolean value representing if a modular inputs
-            specification file exists
+        Returns a boolean value representing if a modular inputs
+        specification file exists
         """
         return self.app.file_exists(
             self.specification_directory_path, self.specification_filename
@@ -115,8 +111,8 @@ class ModularInputs(object):
     # TODO: generalize this to accept the filename and directory
     def get_specification_file(self):
         """Returns:
-            Returns a InputsSpecification object that represents the Modular
-            Inputs specificatoin file.
+        Returns a InputsSpecification object that represents the Modular
+        Inputs specificatoin file.
         """
         return self.app.get_spec(
             self.specification_filename,
@@ -127,8 +123,8 @@ class ModularInputs(object):
     # TODO: generalize this to accept the filename and directory
     def get_raw_specification_file(self):
         """Returns:
-            Returns a string that represents the raw content of the Modular
-            Inputs specification file.
+        Returns a string that represents the raw content of the Modular
+        Inputs specification file.
         """
         return self.app.get_raw_conf(
             self.specification_filename, dir=self.specification_directory_path
@@ -136,8 +132,8 @@ class ModularInputs(object):
 
     def get_specification_app_filepath(self):
         """Returns:
-            Returns a string that represents the absolute file path to Modular
-            Inputs specification file.
+        Returns a string that represents the absolute file path to Modular
+        Inputs specification file.
         """
         return self.app.get_filename(
             self.specification_directory_path, self.specification_filename
@@ -176,7 +172,7 @@ class ModularInputs(object):
 
                     # This pattern is used in order to get an exact match for
                     # the name without checking length of the strings.
-                    file_regex_pattern = "^{}$".format(name)
+                    file_regex_pattern = f"^{name}$"
                     file_name_regex_object = re.compile(file_regex_pattern, regex_flags)
                     found_file_matching_mod_input_name = (
                         re.search(file_name_regex_object, file_base_name) is not None
@@ -204,7 +200,7 @@ class ModularInputs(object):
 
     def has_modular_inputs(self):
         """Returns:
-            A boolean value representing the number of modular inputs detected
+        A boolean value representing the number of modular inputs detected
         """
         return len(list(self.get_modular_inputs())) > 0
 
